# Vulpes

**Vulpes: Test many classification, regression models and clustering algorithms to see which one is most suitable for your dataset.**

Vulpes 🦊 is a Python package that allows you to test many models, whether you want to do classification, regression or clustering in your projects. It calculates many metrics for each model to compare them. It is highly customizable and it contains many features to save time building robust ML models.

If you like this project, please leave a star ⭐ on GitHub !

Alpha version.

Author: Adrien Carrel.

## Installation

Using pip:

```python
pip install vulpes
```

Then, you can use vulpes by importing the package:

```python
import vulpes
```

See examples below.

## Examples

Test:

```python
test
```

## Documentation

Link to the documentation

## Testing

```python
pytest vulpes/tests/
```

## Why Vulpes?

Vulpes stands for: **V**ector (**U**n)supervised **L**earning **P**rogram **E**stimation **S**ystem.

Nah, I'm kidding, I just love foxes, they are cute! The most common and widespread species of fox is the red fox (Vulpes vulpes).

![alt text](https://github.com/AdrienC21/vulpes/blob/main/fox.jpg?raw=true)

## Acknowledgment

- Lazy Predict by Shankar Rao Pandala (and some contributors) for the inspiration. Even though it is older and it offers less functionnalities, it is the first package to my knowledge that, in the same way, allows to test many models.

## License

[MIT](https://choosealicense.com/licenses/mit/)
